@@ -15,12 +15,15 @@ level.
 """
 
 from __future__ import annotations
-from typing import Any, Union
 
 import math
+
+from typing import Any, Optional, Union
+
 import numpy as np
 import pandas as pd
-from samplics.utils import formats
+
+from samplics.utils.formats import dict_to_dataframe, numpy_array
 from samplics.utils.types import Array, DictStrNum, Number
 
 
@@ -392,16 +395,16 @@ class EblupAreaModel:
             Defaults to 100.
         """
 
-        area = formats.numpy_array(area)
-        yhat = formats.numpy_array(yhat)
-        X = formats.numpy_array(X)
+        area = numpy_array(area)
+        yhat = numpy_array(yhat)
+        X = numpy_array(X)
 
-        error_std = formats.numpy_array(error_std)
-        error_std = formats.numpy_array(error_std)
+        error_std = numpy_array(error_std)
+        error_std = numpy_array(error_std)
         if isinstance(b_const, (int, float)):
             b_const = np.asarray(np.ones(area.size) * b_const)
         else:
-            b_const = formats.numpy_array(b_const)
+            b_const = numpy_array(b_const)
 
         if intercept and isinstance(X, np.ndarray):
             X = np.insert(X, 0, 1, axis=1)
@@ -476,20 +479,20 @@ class EblupAreaModel:
             Exception: [description]
         """
 
-        area = formats.numpy_array(area)
+        area = numpy_array(area)
         if not self.fitted:
             raise Exception(
                 "The model must be fitted first with .fit() before running the prediction."
             )
 
-        X = formats.numpy_array(X)
+        X = numpy_array(X)
         if intercept and isinstance(X, np.ndarray):
             X = np.insert(X, 0, 1, axis=1)
 
         if isinstance(b_const, (int, float)):
             b_const = np.asarray(np.ones(area.size) * b_const)
         else:
-            b_const = formats.numpy_array(b_const)
+            b_const = numpy_array(b_const)
 
         point_est, mse, mse1, mse2, g1, g2, g3, g3_star = self._eb_estimates(
             X=X,
@@ -504,15 +507,18 @@ class EblupAreaModel:
         self.area_est = dict(zip(area, point_est))
         self.area_mse = dict(zip(area, mse))
 
-    def to_dataframe(self, col_names: list[str] = ["_area", "_estimate", "_mse"]) -> pd.DataFrame:
+    def to_dataframe(self, col_names: Optional(list) = None) -> pd.DataFrame:
         """Returns a pandas dataframe from dictionaries with same keys and one value per key.
 
         Args:
             col_names (list, optional): list of string to be used for the dataframe columns names.
-                Defaults to ["_area", "_estimate", "_mse"].
+                Defaults to ["_parameter", "_area", "_estimate", "_mse"].
 
         Returns:
             [type]: a pandas dataframe
         """
 
-        return formats.dict_to_dataframe(col_names, self.area_est, self.area_mse)
+        est_df = dict_to_dataframe(col_names, self.area_est, self.area_mse)
+        est_df.iloc[:, 0] = "mean"
+
+        return est_df
