@@ -24,18 +24,17 @@ see Rao, J.N.K. and Molina, I. (2015) [#rm2015]_.
 """
 
 from __future__ import annotations
-from typing import Any, Optional, Union, Callable
+
+from typing import Any, Callable, Optional, Union
 
 import numpy as np
 import pandas as pd
-
 import statsmodels.api as sm
 
-from samplics.utils import formats, basic_functions
-from samplics.utils.types import Array, DictStrNum, Number
-
-from samplics.sae.sae_core_functions import area_stats
 from samplics.sae.eb_unit_model import EbUnitModel
+from samplics.sae.sae_core_functions import area_stats
+from samplics.utils import basic_functions, formats
+from samplics.utils.types import Array, DictStrNum, Number
 
 
 class EllUnitModel:
